ConnectedSingleConnection

Struct ConnectedSingleConnection 

pub struct ConnectedSingleConnection<I, O, C: Decoder<Item = I> + Encoder<O>> {
    pub source: SingleConnectionSource<I, C>,
    pub sink: SingleConnectionSink<O, C>,
}
A connected implementation which only allows a single live connection for the lifetime of the server. The first accepted connection is kept and its sink and stream are exposed; any subsequent connections are ignored.

Fields

source: SingleConnectionSource<I, C>sink: SingleConnectionSink<O, C>